# Generated by Django 3.2.15 on 2023-05-11 23:39

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('magic_notifier', '0003_auto_20220914_1756'),
    ]

    operations = [
        migrations.AlterField(
            model_name='notification',
            name='subject',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
    ]
